==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Output/oss/translations/oss_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_CN">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="30"/>
        <source>OSS Plugin</source>
        <translation>OSS 插件</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>关于 OSS 输出插件</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>Qmmp OSS 输出插件</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Writen by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>作者：Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>源代码基于：Brad Hughes &lt;bhughes@trolltech.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>OSS Plugin Settings</source>
        <translation>OSS 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Device Settings</source>
        <translation>设备设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio device</source>
        <translation>音频设备</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Mixer device</source>
        <translation>混频设备</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="113"/>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="134"/>
        <source>Soundcard</source>
        <translation>声卡</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="210"/>
        <source>Buffer time (ms):</source>
        <translation>缓冲时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="220"/>
        <source>Period time (ms):</source>
        <translation>周期时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>PCM over Master</source>
        <translation type="unfinished">PCM over Master</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="277"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="284"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
</TS>

==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/Output/oss/translations/oss_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>OutputOSSFactory</name>
    <message>
        <location filename="../outputossfactory.cpp" line="36"/>
        <source>OSS Plugin</source>
        <translation>OSS 插件</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="56"/>
        <source>About OSS Output Plugin</source>
        <translation>关于 OSS 输出插件</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="57"/>
        <source>Qmmp OSS Output Plugin</source>
        <translation>Qmmp OSS 输出插件</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="58"/>
        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
        <translation>作者：Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../outputossfactory.cpp" line="59"/>
        <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
        <translation>源代码基于：Brad Hughes &lt;bhughes@trolltech.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS Plugin Settings</source>
        <translation>OSS 插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>设备设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>音频设备</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer device</source>
        <translation>混频设备</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="84"/>
        <source>Advanced Settings</source>
        <translation>高级设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Soundcard</source>
        <translation>声卡</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Buffer time (ms):</source>
        <translation>缓冲时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="170"/>
        <source>Period time (ms):</source>
        <translation>周期时间(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="200"/>
        <source>PCM over Master</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
